@@ -6,24 +6,27 @@ use message::{msg, MessageType};
 impl DevloopConfig {
     pub fn run(&self) {
         let help = self.calculate_help();
-        loop {
-            clear_screen();
+        'main: loop {
+            Command::new("clear").status().expect("clear screen");
             if self.run_tasks() {
                 msg(&MessageType::Success, &format!("Done [{}]:", help), true);
             } else {
                 msg(&MessageType::Fail, "Error.", false);
             }
-            match read_line().as_ref() {
-                "" => continue,
-                "q" => break,
-                action => {
-                    if let Some(task) = self.actions.get(action) {
-                        if !task.execute() {
+            loop {
+                match read_line().as_ref() {
+                    "q" => break 'main,
+                    action => {
+                        if self.actions
+                            .get(action)
+                            .map(|task| task.execute())
+                            .unwrap_or(true)
+                        {
+                            break;
+                        } else {
                             msg(&MessageType::Fail, "Error.", false);
-                            read_line();
+                            // Read line again
                         }
-                    } else {
-                        continue;
                     }
                 }
             }
@@ -55,12 +58,6 @@ impl DevloopConfig {
     }
 }
 
-fn clear_screen() {
-    Command::new("sh").args(&["-c", "clear"]).status().expect(
-        "clear screen",
-    );
-}
-
 fn read_line() -> String {
     use std::io::BufRead;
     let stdin = ::std::io::stdin();
